# cGAN Project

This is a Conditional Generative Adversarial Network (cGAN) project that allows you to train on your own dataset. The project generates images based on the specified data and saves a trained generator model along with a dictionary of classes to indices.
